==> libphp-swiftmailer_4.0.6.orig.tar.gz: Swift-4.0.6/lib/classes/Swift/Transport/SimpleMailInvoker.php <==
<?php

/*
 Invokes the mail() function in Swift Mailer.
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 */
 
//@require 'Swift/Transport/MailInvoker.php';

/**
 * This is the implementation class for {@link Swift_Transport_MailInvoker}.
 * 
 * @package Swift
 * @subpackage Transport
 * @author Chris Corbyn
 */
class Swift_Transport_SimpleMailInvoker implements Swift_Transport_MailInvoker
{
  
  /**
   * Send mail via the mail() function.
   * 
   * This method takes the same arguments as PHP mail().
   * 
   * @param string $to
   * @param string $subject
   * @param string $body
   * @param string $headers
   * @param string $extraParams
   * 
   * @return boolean
   */
  public function mail($to, $subject, $body, $headers = null, $extraParams = null)
  {
    if (!ini_get('safe_mode'))
    {
      return mail($to, $subject, $body, $headers, $extraParams);
    }
    else
    {
      return mail($to, $subject, $body, $headers);      
    }
  }
  
}

==> libphp-swiftmailer_4.2.1.orig.tar.gz: Swift-4.2.1/lib/classes/Swift/Transport/SimpleMailInvoker.php <==
<?php

/*
 Invokes the mail() function in Swift Mailer.

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.

 */

/**
 * This is the implementation class for {@link Swift_Transport_MailInvoker}.
 *
 * @package Swift
 * @subpackage Transport
 * @author Chris Corbyn
 */
class Swift_Transport_SimpleMailInvoker implements Swift_Transport_MailInvoker
{
    /**
     * Send mail via the mail() function.
     *
     * This method takes the same arguments as PHP mail().
     *
     * @param string $to
     * @param string $subject
     * @param string $body
     * @param string $headers
     * @param string $extraParams
     *
     * @return boolean
     */
    public function mail($to, $subject, $body, $headers = null, $extraParams = null)
    {
        if (!ini_get('safe_mode')) {
            return @mail($to, $subject, $body, $headers, $extraParams);
        } else {
            return @mail($to, $subject, $body, $headers);
        }
    }
}
